@@ -27,19 +27,19 @@ extern "C" {
 #endif
 
 /*!
-	\mainpage libscap documentation
+    \mainpage libscap documentation
 
-	\section Introduction
+    \section Introduction
 
-	libscap is the low-level component that exports the following functionality:
-	- live capture control (start/stop/pause...)
-	- trace file management
-	- event retrieval
-	- extraction of system state from /proc
+    libscap is the low-level component that exports the following functionality:
+    - live capture control (start/stop/pause...)
+    - trace file management
+    - event retrieval
+    - extraction of system state from /proc
 
-	This manual includes the following sections:
-	- \ref scap_defs
-	- \ref scap_functs
+    This manual includes the following sections:
+    - \ref scap_defs
+    - \ref scap_functs
 */
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -124,11 +124,10 @@ struct scap_vtable;
 /*!
   \brief Statistics about an in progress capture
 */
-typedef struct scap_stats
-{
-	uint64_t n_evts; ///< Total number of events that were received by the driver.
-	uint64_t n_drops; ///< Number of dropped events.
-	uint64_t n_drops_buffer; ///< Number of dropped events caused by full buffer.
+typedef struct scap_stats {
+	uint64_t n_evts;          ///< Total number of events that were received by the driver.
+	uint64_t n_drops;         ///< Number of dropped events.
+	uint64_t n_drops_buffer;  ///< Number of dropped events caused by full buffer.
 	uint64_t n_drops_buffer_clone_fork_enter;
 	uint64_t n_drops_buffer_clone_fork_exit;
 	uint64_t n_drops_buffer_execve_enter;
@@ -143,19 +142,20 @@ typedef struct scap_stats
 	uint64_t n_drops_buffer_other_interest_exit;
 	uint64_t n_drops_buffer_close_exit;
 	uint64_t n_drops_buffer_proc_exit;
-	uint64_t n_drops_scratch_map; ///< Number of dropped events caused by full frame scratch map.
-	uint64_t n_drops_pf; ///< Number of dropped events caused by invalid memory access.
-	uint64_t n_drops_bug; ///< Number of dropped events caused by an invalid condition in the kernel instrumentation.
-	uint64_t n_preemptions; ///< Number of preemptions.
-	uint64_t n_suppressed; ///< Number of events skipped due to the tid being in a set of suppressed tids.
-	uint64_t n_tids_suppressed; ///< Number of threads currently being suppressed.
-}scap_stats;
+	uint64_t n_drops_scratch_map;  ///< Number of dropped events caused by full frame scratch map.
+	uint64_t n_drops_pf;           ///< Number of dropped events caused by invalid memory access.
+	uint64_t n_drops_bug;        ///< Number of dropped events caused by an invalid condition in the
+	                             ///< kernel instrumentation.
+	uint64_t n_preemptions;      ///< Number of preemptions.
+	uint64_t n_suppressed;       ///< Number of events skipped due to the tid being in a set of
+	                             ///< suppressed tids.
+	uint64_t n_tids_suppressed;  ///< Number of threads currently being suppressed.
+} scap_stats;
 
 /*!
   \brief File Descriptor type
 */
-typedef enum scap_fd_type
-{
+typedef enum scap_fd_type {
 	SCAP_FD_UNINITIALIZED = -1,
 	SCAP_FD_UNKNOWN = 0,
 	SCAP_FD_FILE = 1,
@@ -179,136 +179,137 @@ typedef enum scap_fd_type
 	SCAP_FD_IOURING = 19,
 	SCAP_FD_MEMFD = 20,
 	SCAP_FD_PIDFD = 21
-}scap_fd_type;
+} scap_fd_type;
 
 /*!
   \brief Socket type / transport protocol
 */
-typedef enum scap_l4_proto
-{
-	SCAP_L4_UNKNOWN = 0, ///< unknown protocol, likely caused by some parsing problem
-	SCAP_L4_NA = 1, ///< protocol not available, because the fd is not a socket
+typedef enum scap_l4_proto {
+	SCAP_L4_UNKNOWN = 0,  ///< unknown protocol, likely caused by some parsing problem
+	SCAP_L4_NA = 1,       ///< protocol not available, because the fd is not a socket
 	SCAP_L4_TCP = 2,
 	SCAP_L4_UDP = 3,
 	SCAP_L4_ICMP = 4,
-	SCAP_L4_RAW = 5, ///< Raw socket
-}scap_l4_proto;
+	SCAP_L4_RAW = 5,  ///< Raw socket
+} scap_l4_proto;
 
 /*!
   \brief Information about a file descriptor
 */
-typedef struct scap_fdinfo
-{
-	int64_t fd; ///< The FD number, which uniquely identifies this file descriptor.
-	uint64_t ino; ///< The inode.
-	scap_fd_type type; ///< This file descriptor's type.
-	union
-	{
-		struct
-		{
-		  uint32_t sip; ///< Source IP
-		  uint32_t dip; ///< Destination IP
-		  uint16_t sport; ///< Source port
-		  uint16_t dport; ///< Destination port
-		  uint8_t l4proto; ///< Transport protocol. See \ref scap_l4_proto.
-		} ipv4info; ///< Information specific to IPv4 sockets
-		struct
-		{
-			uint32_t sip[4]; ///< Source IP
-			uint32_t dip[4]; ///< Destination IP
-			uint16_t sport; ///< Source Port
-			uint16_t dport; ///< Destination Port
-			uint8_t l4proto; ///< Transport protocol. See \ref scap_l4_proto.
-		} ipv6info; ///< Information specific to IPv6 sockets
-		struct
-		{
-		  uint32_t ip; ///< Local IP
-		  uint16_t port; ///< Local Port
-		  uint8_t l4proto; ///< Transport protocol. See \ref scap_l4_proto.
-		} ipv4serverinfo; ///< Information specific to IPv4 server sockets, e.g. sockets used for bind().
-		struct
-		{
-			uint32_t ip[4]; ///< Local IP
-			uint16_t port; ///< Local Port
-			uint8_t l4proto; ///< Transport protocol. See \ref scap_l4_proto.
-		} ipv6serverinfo; ///< Information specific to IPv6 server sockets, e.g. sockets used for bind().
-		struct
-		{
-			uint64_t source; ///< Source socket endpoint
-		  	uint64_t destination; ///< Destination socket endpoint
-			char fname[SCAP_MAX_PATH_SIZE]; ///< Name associated to this unix socket
-		} unix_socket_info; ///< Information specific to unix sockets
-		struct
-		{
-			uint32_t open_flags; ///< Flags associated with the file
-			char fname[SCAP_MAX_PATH_SIZE]; ///< Name associated to this file
-			uint32_t mount_id; ///< The id of the vfs mount the file is in until we find dev major:minor
-			uint32_t dev; ///< Major/minor number of the device containing this file
-		} regularinfo; ///< Information specific to regular files
+typedef struct scap_fdinfo {
+	int64_t fd;         ///< The FD number, which uniquely identifies this file descriptor.
+	uint64_t ino;       ///< The inode.
+	scap_fd_type type;  ///< This file descriptor's type.
+	union {
+		struct {
+			uint32_t sip;     ///< Source IP
+			uint32_t dip;     ///< Destination IP
+			uint16_t sport;   ///< Source port
+			uint16_t dport;   ///< Destination port
+			uint8_t l4proto;  ///< Transport protocol. See \ref scap_l4_proto.
+		} ipv4info;           ///< Information specific to IPv4 sockets
+		struct {
+			uint32_t sip[4];  ///< Source IP
+			uint32_t dip[4];  ///< Destination IP
+			uint16_t sport;   ///< Source Port
+			uint16_t dport;   ///< Destination Port
+			uint8_t l4proto;  ///< Transport protocol. See \ref scap_l4_proto.
+		} ipv6info;           ///< Information specific to IPv6 sockets
+		struct {
+			uint32_t ip;      ///< Local IP
+			uint16_t port;    ///< Local Port
+			uint8_t l4proto;  ///< Transport protocol. See \ref scap_l4_proto.
+		} ipv4serverinfo;  ///< Information specific to IPv4 server sockets, e.g. sockets used for
+		                   ///< bind().
+		struct {
+			uint32_t ip[4];   ///< Local IP
+			uint16_t port;    ///< Local Port
+			uint8_t l4proto;  ///< Transport protocol. See \ref scap_l4_proto.
+		} ipv6serverinfo;  ///< Information specific to IPv6 server sockets, e.g. sockets used for
+		                   ///< bind().
+		struct {
+			uint64_t source;                 ///< Source socket endpoint
+			uint64_t destination;            ///< Destination socket endpoint
+			char fname[SCAP_MAX_PATH_SIZE];  ///< Name associated to this unix socket
+		} unix_socket_info;                  ///< Information specific to unix sockets
+		struct {
+			uint32_t open_flags;             ///< Flags associated with the file
+			char fname[SCAP_MAX_PATH_SIZE];  ///< Name associated to this file
+			uint32_t mount_id;  ///< The id of the vfs mount the file is in until we find dev
+			                    ///< major:minor
+			uint32_t dev;       ///< Major/minor number of the device containing this file
+		} regularinfo;          ///< Information specific to regular files
 		char fname[SCAP_MAX_PATH_SIZE];  ///< The name for file system FDs
-	}info;
-	UT_hash_handle hh; ///< makes this structure hashable
-}scap_fdinfo;
+	} info;
+	UT_hash_handle hh;  ///< makes this structure hashable
+} scap_fdinfo;
 
 /*!
   \brief Process information
 */
-typedef struct scap_threadinfo
-{
-	uint64_t tid; ///< The thread/task id.
-	uint64_t pid; ///< The id of the process containing this thread. In single thread processes, this is equal to tid.
-	uint64_t ptid; ///< The id of the thread that created this thread.
-	uint64_t sid; ///< The session id of the process containing this thread.
-	uint64_t vpgid; ///< The process group of this thread, as seen from its current pid namespace
-	char comm[SCAP_MAX_PATH_SIZE+1]; ///< Command name (e.g. "top")
-	char exe[SCAP_MAX_PATH_SIZE+1]; ///< argv[0] (e.g. "sshd: user@pts/4")
-	char exepath[SCAP_MAX_PATH_SIZE+1]; ///< full executable path
-	bool exe_writable; ///< true if the original executable is writable by the same user that spawned it.
-	bool exe_upper_layer; //< True if the original executable belongs to upper layer in overlayfs
-	bool exe_from_memfd;  //< True if the original executable is stored in pathless memory referenced by a memfd
-	char args[SCAP_MAX_ARGS_SIZE+1]; ///< Command line arguments (e.g. "-d1")
-	uint16_t args_len; ///< Command line arguments length
-	char env[SCAP_MAX_ENV_SIZE+1]; ///< Environment
-	uint16_t env_len; ///< Environment length
-	char cwd[SCAP_MAX_PATH_SIZE+1]; ///< The current working directory
-	int64_t fdlimit; ///< The maximum number of files this thread is allowed to open
-	uint32_t flags; ///< the process flags.
-	uint32_t uid; ///< user id
-	uint32_t gid; ///< group id
-	uint64_t cap_permitted; ///< permitted capabilities
-	uint64_t cap_effective; ///< effective capabilities
-	uint64_t cap_inheritable; ///< inheritable capabilities
-	uint64_t exe_ino; ///< executable inode ino
-	uint64_t exe_ino_ctime; ///< executable inode ctime (last status change time)
-	uint64_t exe_ino_mtime; ///< executable inode mtime (last modification time)
-	uint64_t exe_ino_ctime_duration_clone_ts; ///< duration in ns between executable inode ctime (last status change time) and clone_ts
-	uint64_t exe_ino_ctime_duration_pidns_start; ///< duration in ns between pidns start ts and executable inode ctime (last status change time) if pidns start predates ctime
-	uint32_t vmsize_kb; ///< total virtual memory (as kb)
-	uint32_t vmrss_kb; ///< resident non-swapped memory (as kb)
-	uint32_t vmswap_kb; ///< swapped memory (as kb)
-	uint64_t pfmajor; ///< number of major page faults since start
-	uint64_t pfminor; ///< number of minor page faults since start
-	int64_t vtid;  ///< The virtual id of this thread.
-	int64_t vpid; ///< The virtual id of the process containing this thread. In single thread threads, this is equal to vtid.
-	uint64_t pidns_init_start_ts; ///<The pid_namespace init task start_time ts.
+typedef struct scap_threadinfo {
+	uint64_t tid;    ///< The thread/task id.
+	uint64_t pid;    ///< The id of the process containing this thread. In single thread processes,
+	                 ///< this is equal to tid.
+	uint64_t ptid;   ///< The id of the thread that created this thread.
+	uint64_t sid;    ///< The session id of the process containing this thread.
+	uint64_t vpgid;  ///< The process group of this thread, as seen from its current pid namespace
+	char comm[SCAP_MAX_PATH_SIZE + 1];     ///< Command name (e.g. "top")
+	char exe[SCAP_MAX_PATH_SIZE + 1];      ///< argv[0] (e.g. "sshd: user@pts/4")
+	char exepath[SCAP_MAX_PATH_SIZE + 1];  ///< full executable path
+	bool exe_writable;     ///< true if the original executable is writable by the same user that
+	                       ///< spawned it.
+	bool exe_upper_layer;  //< True if the original executable belongs to upper layer in overlayfs
+	bool exe_lower_layer;  //< True if the original executable belongs to lower layer in overlayfs
+	bool exe_from_memfd;   //< True if the original executable is stored in pathless memory
+	                       // referenced by a memfd
+	char args[SCAP_MAX_ARGS_SIZE + 1];  ///< Command line arguments (e.g. "-d1")
+	uint16_t args_len;                  ///< Command line arguments length
+	char env[SCAP_MAX_ENV_SIZE + 1];    ///< Environment
+	uint16_t env_len;                   ///< Environment length
+	char cwd[SCAP_MAX_PATH_SIZE + 1];   ///< The current working directory
+	int64_t fdlimit;           ///< The maximum number of files this thread is allowed to open
+	uint32_t flags;            ///< the process flags.
+	uint32_t uid;              ///< user id
+	uint32_t gid;              ///< group id
+	uint64_t cap_permitted;    ///< permitted capabilities
+	uint64_t cap_effective;    ///< effective capabilities
+	uint64_t cap_inheritable;  ///< inheritable capabilities
+	uint64_t exe_ino;          ///< executable inode ino
+	uint64_t exe_ino_ctime;    ///< executable inode ctime (last status change time)
+	uint64_t exe_ino_mtime;    ///< executable inode mtime (last modification time)
+	uint64_t exe_ino_ctime_duration_clone_ts;     ///< duration in ns between executable inode ctime
+	                                              ///< (last status change time) and clone_ts
+	uint64_t exe_ino_ctime_duration_pidns_start;  ///< duration in ns between pidns start ts and
+	                                              ///< executable inode ctime (last status change
+	                                              ///< time) if pidns start predates ctime
+	uint32_t vmsize_kb;                           ///< total virtual memory (as kb)
+	uint32_t vmrss_kb;                            ///< resident non-swapped memory (as kb)
+	uint32_t vmswap_kb;                           ///< swapped memory (as kb)
+	uint64_t pfmajor;                             ///< number of major page faults since start
+	uint64_t pfminor;                             ///< number of minor page faults since start
+	int64_t vtid;                                 ///< The virtual id of this thread.
+	int64_t vpid;  ///< The virtual id of the process containing this thread. In single thread
+	               ///< threads, this is equal to vtid.
+	uint64_t pidns_init_start_ts;  ///< The pid_namespace init task start_time ts.
 	struct scap_cgroup_set cgroups;
 	char root[SCAP_MAX_PATH_SIZE + 1];
-	int filtered_out; ///< nonzero if this entry should not be saved to file
-	scap_fdinfo* fdlist; ///< The fd table for this process
-	uint64_t clone_ts; ///< When the clone that started this process happened.
-	uint32_t tty; ///< Number of controlling terminal
-	uint32_t loginuid; ///< loginuid (auid)
+	int filtered_out;     ///< nonzero if this entry should not be saved to file
+	scap_fdinfo* fdlist;  ///< The fd table for this process
+	uint64_t clone_ts;    ///< When the clone that started this process happened.
+	uint32_t tty;         ///< Number of controlling terminal
+	uint32_t loginuid;    ///< loginuid (auid)
 
-	UT_hash_handle hh; ///< makes this structure hashable
-}scap_threadinfo;
+	UT_hash_handle hh;  ///< makes this structure hashable
+} scap_threadinfo;
 
 /*!
   \brief Mount information
 */
 typedef struct scap_mountinfo {
-	uint64_t mount_id; ///< mount id from /proc/self/mountinfo
-	uint32_t dev; ///< device number
-	UT_hash_handle hh; ///< makes this structure hashable
+	uint64_t mount_id;  ///< mount id from /proc/self/mountinfo
+	uint32_t dev;       ///< device number
+	UT_hash_handle hh;  ///< makes this structure hashable
 } scap_mountinfo;
 
 //
@@ -324,58 +325,54 @@ typedef struct scap_mountinfo {
 /*!
   \brief Interface address type
 */
-typedef enum scap_ifinfo_type
-{
+typedef enum scap_ifinfo_type {
 	SCAP_II_UNKNOWN = 0,
 	SCAP_II_IPV4 = 1,
 	SCAP_II_IPV6 = 2,
 	SCAP_II_IPV4_NOLINKSPEED = 3,
 	SCAP_II_IPV6_NOLINKSPEED = 4,
-}scap_ifinfo_type;
+} scap_ifinfo_type;
 
 /*!
   \brief IPv4 interface address information
 */
-typedef struct scap_ifinfo_ipv4
-{
+typedef struct scap_ifinfo_ipv4 {
 	// NB: new fields must be appended
-	uint16_t type; ///< Interface type
+	uint16_t type;  ///< Interface type
 	uint16_t ifnamelen;
-	uint32_t addr; ///< Interface address
-	uint32_t netmask; ///< Interface netmask
-	uint32_t bcast; ///< Interface broadcast address
-	uint64_t linkspeed; ///< Interface link speed
-	char ifname[SCAP_MAX_PATH_SIZE]; ///< interface name (e.g. "eth0")
-}scap_ifinfo_ipv4;
+	uint32_t addr;                    ///< Interface address
+	uint32_t netmask;                 ///< Interface netmask
+	uint32_t bcast;                   ///< Interface broadcast address
+	uint64_t linkspeed;               ///< Interface link speed
+	char ifname[SCAP_MAX_PATH_SIZE];  ///< interface name (e.g. "eth0")
+} scap_ifinfo_ipv4;
 
 /*!
   \brief IPv6 interface address information
 */
-typedef struct scap_ifinfo_ipv6
-{
+typedef struct scap_ifinfo_ipv6 {
 	// NB: new fields must be appended
 	uint16_t type;
 	uint16_t ifnamelen;
-	char addr[SCAP_IPV6_ADDR_LEN]; ///< Interface address
-	char netmask[SCAP_IPV6_ADDR_LEN]; ///< Interface netmask
-	char bcast[SCAP_IPV6_ADDR_LEN]; ///< Interface broadcast address
-	uint64_t linkspeed; ///< Interface link speed
-	char ifname[SCAP_MAX_PATH_SIZE]; ///< interface name (e.g. "eth0")
-}scap_ifinfo_ipv6;
+	char addr[SCAP_IPV6_ADDR_LEN];     ///< Interface address
+	char netmask[SCAP_IPV6_ADDR_LEN];  ///< Interface netmask
+	char bcast[SCAP_IPV6_ADDR_LEN];    ///< Interface broadcast address
+	uint64_t linkspeed;                ///< Interface link speed
+	char ifname[SCAP_MAX_PATH_SIZE];   ///< interface name (e.g. "eth0")
+} scap_ifinfo_ipv6;
 
 #pragma pack(pop)
 
 /*!
   \brief List of the machine network interfaces
 */
-typedef struct scap_addrlist
-{
-	uint32_t n_v4_addrs; ///< Number of IPv4 addresses
-	uint32_t n_v6_addrs; ///< Number of IPv6 addresses
-	uint32_t totlen; ///< For internal use
-	scap_ifinfo_ipv4* v4list; ///< List of IPv4 Addresses
-	scap_ifinfo_ipv6* v6list; ///< List of IPv6 Addresses
-}scap_addrlist;
+typedef struct scap_addrlist {
+	uint32_t n_v4_addrs;       ///< Number of IPv4 addresses
+	uint32_t n_v6_addrs;       ///< Number of IPv6 addresses
+	uint32_t totlen;           ///< For internal use
+	scap_ifinfo_ipv4* v4list;  ///< List of IPv4 Addresses
+	scap_ifinfo_ipv6* v6list;  ///< List of IPv6 Addresses
+} scap_addrlist;
 
 #define MAX_CREDENTIALS_STR_LEN 256
 #define USERBLOCK_TYPE_USER 0
@@ -384,35 +381,32 @@ typedef struct scap_addrlist
 /*!
   \brief Information about one of the machine users
 */
-typedef struct scap_userinfo
-{
-	uint32_t uid; ///< User ID
-	uint32_t gid; ///< Group ID
-	char name[MAX_CREDENTIALS_STR_LEN]; ///< Username
-	char homedir[SCAP_MAX_PATH_SIZE]; ///< Home directory
-	char shell[SCAP_MAX_PATH_SIZE]; ///< Shell program
-}scap_userinfo;
+typedef struct scap_userinfo {
+	uint32_t uid;                        ///< User ID
+	uint32_t gid;                        ///< Group ID
+	char name[MAX_CREDENTIALS_STR_LEN];  ///< Username
+	char homedir[SCAP_MAX_PATH_SIZE];    ///< Home directory
+	char shell[SCAP_MAX_PATH_SIZE];      ///< Shell program
+} scap_userinfo;
 
 /*!
   \brief Information about one of the machine user groups
 */
-typedef struct scap_groupinfo
-{
-	uint32_t gid; ///< Group ID
-	char name[MAX_CREDENTIALS_STR_LEN]; ///< Group name
-}scap_groupinfo;
+typedef struct scap_groupinfo {
+	uint32_t gid;                        ///< Group ID
+	char name[MAX_CREDENTIALS_STR_LEN];  ///< Group name
+} scap_groupinfo;
 
 /*!
   \brief List of the machine users and groups
 */
-typedef struct scap_userlist
-{
-	uint32_t nusers; ///< Number of users
-	uint32_t ngroups; ///< Number of groups
-	uint32_t totsavelen; ///< For internal use
-	scap_userinfo* users;  ///< User list
-	scap_groupinfo* groups; ///< Group list
-}scap_userlist;
+typedef struct scap_userlist {
+	uint32_t nusers;         ///< Number of users
+	uint32_t ngroups;        ///< Number of groups
+	uint32_t totsavelen;     ///< For internal use
+	scap_userinfo* users;    ///< User list
+	scap_groupinfo* groups;  ///< Group list
+} scap_userlist;
 
 //
 // Misc definitions
@@ -421,23 +415,18 @@ typedef struct scap_userlist
 /*!
   \brief Indicates if an event is an enter one or an exit one
 */
-typedef enum event_direction
-{
-	SCAP_ED_IN = 0,
-	SCAP_ED_OUT = 1
-}event_direction;
+typedef enum event_direction { SCAP_ED_IN = 0, SCAP_ED_OUT = 1 } event_direction;
 
 /*!
   \brief Flags for scap_dump
 */
-typedef enum scap_dump_flags
-{
+typedef enum scap_dump_flags {
 	SCAP_DF_NONE = 0,
-	SCAP_DF_STATE_ONLY = 1,		///< The event should be used for state update but it should
-								///< not be shown to the user
+	SCAP_DF_STATE_ONLY = 1,  ///< The event should be used for state update but it should
+	                         ///< not be shown to the user
 	// SCAP_DF_TRACER = (1 << 1),	/// note: deprecated
-	SCAP_DF_LARGE = (1 << 2)	///< This event has large payload (up to UINT_MAX Bytes, ie 4GB)
-}scap_dump_flags;
+	SCAP_DF_LARGE = (1 << 2)  ///< This event has large payload (up to UINT_MAX Bytes, ie 4GB)
+} scap_dump_flags;
 
 /*!
   \brief Structure used to pass a buffer and its size.
@@ -459,13 +448,6 @@ typedef struct scap_const_sized_buffer scap_const_sized_buffer;
 
 /*@}*/
 
-///////////////////////////////////////////////////////////////////////////////
-// Structs and defines used internally
-///////////////////////////////////////////////////////////////////////////////
-
-#define IN
-#define OUT
-
 ///////////////////////////////////////////////////////////////////////////////
 // API functions
 ///////////////////////////////////////////////////////////////////////////////
@@ -514,7 +496,10 @@ int32_t scap_init(scap_t* handle, scap_open_args* oargs, const struct scap_vtabl
 
   \return The capture instance handle in case of success. NULL in case of failure.
 */
-scap_t* scap_open(scap_open_args* oargs, const struct scap_vtable* vtable, char* error, int32_t* rc);
+scap_t* scap_open(scap_open_args* oargs,
+                  const struct scap_vtable* vtable,
+                  char* error,
+                  int32_t* rc);
 
 /*!
   \brief Deinitialize a capture handle.
@@ -543,10 +528,10 @@ void scap_close(scap_t* handle);
 /*!
   \brief Restart the current event capture.
     Only supported for captures in SCAP_MODE_CAPTURE mode.
-	This deinitializes the scap internal state, and then re-initializes
-	it by trying to read the scap header section. The underlying instance
-	of scap_reader_t is preserved, and the header section is read starting
-	from its current offset.
+    This deinitializes the scap internal state, and then re-initializes
+    it by trying to read the scap header section. The underlying instance
+    of scap_reader_t is preserved, and the header section is read starting
+    from its current offset.
 
   \param handle Handle to the capture instance.
 */
@@ -566,17 +551,18 @@ uint64_t scap_max_buf_used(scap_t* handle);
   \brief Get the next event from the from the given capture instance
 
   \param handle Handle to the capture instance.
-  \param pevent User-provided event pointer that will be initialized with address of the event.
-  \param pdevid User-provided event pointer that will be initialized with the ID of the device
-    where the event was captured.
-  \param pflags User-provided event pointer that will be initialized with the flags of the event.
+  \param pevent [out] User-provided event pointer that will be initialized with address of the
+  event. \param pdevid [out] User-provided event pointer that will be initialized with the ID of the
+  device where the event was captured. \param pflags [out] User-provided event pointer that will be
+  initialized with the flags of the event.
 
   \return SCAP_SUCCESS if the call is successful and pevent, pcpuid and pflags contain valid data.
    SCAP_TIMEOUT in case the read timeout expired and no event is available.
    SCAP_EOF when the end of an offline capture is reached.
-   On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain the cause of the error.
+   On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain the cause of the
+  error.
 */
-int32_t scap_next(scap_t* handle, OUT scap_evt** pevent, OUT uint16_t* pcpuid, OUT uint32_t* pflags);
+int32_t scap_next(scap_t* handle, scap_evt** pevent, uint16_t* pcpuid, uint32_t* pflags);
 
 /*!
   \brief Get the length of an event
@@ -636,46 +622,61 @@ int64_t scap_get_readfile_offset(scap_t* handle);
   \brief Return the capture statistics for the given capture handle.
 
   \param handle Handle to the capture instance.
-  \param stats Pointer to a \ref scap_stats structure that will be filled with the
+  \param stats [out] Pointer to a \ref scap_stats structure that will be filled with the
   statistics.
 
   \return SCAP_SECCESS if the call is successful.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain
    the cause of the error.
 */
-int32_t scap_get_stats(scap_t* handle, OUT scap_stats* stats);
+int32_t scap_get_stats(scap_t* handle, scap_stats* stats);
 
 /*!
   \brief Get engine statistics (including counters and `bpftool prog show` like stats)
 
   \param handle Handle to the capture instance.
   \param flags holding statistics category flags.
-  \param nstats Pointer reflecting number of statistics in returned buffer.
-  \param rc Pointer to return code.
+  \param nstats [out] Pointer reflecting number of statistics in returned buffer.
+  \param rc [out] Pointer to return code.
 
   \return Pointer to a \ref metrics_v2 structure filled with the statistics.
 */
-const struct metrics_v2* scap_get_stats_v2(scap_t* handle, uint32_t flags, OUT uint32_t* nstats, OUT int32_t* rc);
+const struct metrics_v2* scap_get_stats_v2(scap_t* handle,
+                                           uint32_t flags,
+                                           uint32_t* nstats,
+                                           int32_t* rc);
 
 /*!
-  \brief Returns the set of ppm_sc whose events have EF_MODIFIES_STATE flag or whose syscall have UF_NEVER_DROP flag.
+  \brief Returns the set of ppm_sc whose events have EF_MODIFIES_STATE flag or whose syscall have
+  UF_NEVER_DROP flag.
+
+  \param ppm_sc_array [out] the array of ppm_sc that had their state modified
 */
-int scap_get_modifies_state_ppm_sc(OUT uint8_t ppm_sc_array[PPM_SC_MAX]);
+int scap_get_modifies_state_ppm_sc(uint8_t ppm_sc_array[PPM_SC_MAX]);
 
 /*!
   \brief Take an array of `ppm_sc` as input and provide the associated array of events as output.
+
+  \param ppm_sc_array [in] the `ppm_sc` to look for
+  \param events_array [out] the array of events associated to the provided `ppm_sc`s
 */
-int scap_get_events_from_ppm_sc(IN const uint8_t ppm_sc_array[PPM_SC_MAX], OUT uint8_t events_array[PPM_EVENT_MAX]);
+int scap_get_events_from_ppm_sc(const uint8_t ppm_sc_array[PPM_SC_MAX],
+                                uint8_t events_array[PPM_EVENT_MAX]);
 
 /*!
-  \brief Take an array of `ppm_event_code` as input and provide the associated array of ppm_sc as output.
+  \brief Take an array of `ppm_event_code` as input and provide the associated array of ppm_sc as
+  output.
+
+  \param events_array [in] the array of events to look for
+  \param ppm_sc_array [out] the array of `ppm_sc`s associated to the provided events
 */
-int scap_get_ppm_sc_from_events(IN const uint8_t events_array[PPM_EVENT_MAX], OUT uint8_t ppm_sc_array[PPM_SC_MAX]);
+int scap_get_ppm_sc_from_events(const uint8_t events_array[PPM_EVENT_MAX],
+                                uint8_t ppm_sc_array[PPM_SC_MAX]);
 
 /*!
   \brief Given a name, returns associated ppm_sc.
 */
-ppm_sc_code scap_ppm_sc_from_name(const char *name);
+ppm_sc_code scap_ppm_sc_from_name(const char* name);
 
 /*!
   \brief Convert a native syscall nr to ppm_sc
@@ -805,41 +806,54 @@ const char* scap_get_host_root();
 /*!
   \brief Check if the current engine name matches the provided engine_name
 */
-bool scap_check_current_engine(scap_t *handle, const char* engine_name);
+bool scap_check_current_engine(scap_t* handle, const char* engine_name);
 
 /*!
   \brief Get (at most) n parameters for this event.
 
   \param e The scap event.
-  \param params An array large enough to contain at least one entry per event parameter (which is at most PPM_MAX_EVENT_PARAMS).
+  \param params An array large enough to contain at least one entry per event parameter (which is at
+  most PPM_MAX_EVENT_PARAMS).
  */
-uint32_t scap_event_decode_params(const scap_evt *e, struct scap_sized_buffer *params);
+uint32_t scap_event_decode_params(const scap_evt* e, struct scap_sized_buffer* params);
 
 /*!
   \brief Create an event from the parameters given as arguments.
 
-  Create any event from the event_table passing the type, n and the parameters as variadic arguments as follows:
+  Create any event from the event_table passing the type, n and the parameters as variadic arguments
+  as follows:
    - Any integer type is passed from the correct type
    - String types (including PT_FSPATH, PT_FSRELPATH) are passed via a null-terminated char*
-   - Buffer types, variable size types and similar, including PT_BYTEBUF, PT_SOCKTUPLE are passed with
-     a struct scap_const_sized_buffer
+   - Buffer types, variable size types and similar, including PT_BYTEBUF, PT_SOCKTUPLE are passed
+  with a struct scap_const_sized_buffer
 
-  If the event was written successfully, SCAP_SUCCESS is returned. If the supplied buffer is not large enough to contain
-  the event, SCAP_INPUT_TOO_SMALL is returned and event_size is set with the required size to contain the entire event.
+  If the event was written successfully, SCAP_SUCCESS is returned. If the supplied buffer is not
+  large enough to contain the event, SCAP_INPUT_TOO_SMALL is returned and event_size is set with the
+  required size to contain the entire event.
 
   \param event_buf The buffer where to store the encoded event.
   \param event_size Output value that will be filled with the size of the event.
   \param error A pointer to a scap error string to be filled in case of error.
   \param event_type The event type (normally PPME_*)
-  \param n The number of parameters for this event. This is required as the number of parameters used for each event can change between versions.
-  \param ...
-  \return int32_t The error value. If the event was written successfully, SCAP_SUCCESS is returned.
-  If the supplied buffer is not large enough for the event SCAP_INPUT_TOO_SMALL is returned and event_size
-  is set with the required size to contain the entire event. In other error cases, SCAP_FAILURE is returned.
+  \param n The number of parameters for this event. This is required as the number of parameters
+  used for each event can change between versions. \param ... \return int32_t The error value. If
+  the event was written successfully, SCAP_SUCCESS is returned. If the supplied buffer is not large
+  enough for the event SCAP_INPUT_TOO_SMALL is returned and event_size is set with the required size
+  to contain the entire event. In other error cases, SCAP_FAILURE is returned.
 
  */
-int32_t scap_event_encode_params(struct scap_sized_buffer event_buf, size_t *event_size, char *error, ppm_event_code event_type, uint32_t n, ...);
-int32_t scap_event_encode_params_v(struct scap_sized_buffer event_buf, size_t *event_size, char *error, ppm_event_code event_type, uint32_t n, va_list args);
+int32_t scap_event_encode_params(struct scap_sized_buffer event_buf,
+                                 size_t* event_size,
+                                 char* error,
+                                 ppm_event_code event_type,
+                                 uint32_t n,
+                                 ...);
+int32_t scap_event_encode_params_v(struct scap_sized_buffer event_buf,
+                                   size_t* event_size,
+                                   char* error,
+                                   ppm_event_code event_type,
+                                   uint32_t n,
+                                   va_list args);
 
 /*@}*/
 
@@ -856,8 +870,13 @@ uint64_t scap_get_engine_flags(scap_t* handle);
 //
 uint32_t scap_get_ndevs(scap_t* handle);
 
-// Retrieve a buffer of events from one of the cpus
-extern int32_t scap_readbuf(scap_t* handle, uint32_t cpuid, OUT char** buf, OUT uint32_t* len);
+/*
+ * \brief Retrieve a buffer of events from one of the cpus
+ *
+ * \param buf [out] buffer holding the returned events
+ * \param len [out] number of bytes read into buf
+ */
+extern int32_t scap_readbuf(scap_t* handle, uint32_t cpuid, char** buf, uint32_t* len);
 
 #ifdef PPM_ENABLE_SENTINEL
 // Get the sentinel at the beginning of the event
@@ -868,8 +887,8 @@ int32_t scap_stop_dropping_mode(scap_t* handle);
 int32_t scap_start_dropping_mode(scap_t* handle, uint32_t sampling_ratio);
 int32_t scap_enable_dynamic_snaplen(scap_t* handle);
 int32_t scap_disable_dynamic_snaplen(scap_t* handle);
-uint64_t scap_ftell(scap_t *handle);
-void scap_fseek(scap_t *handle, uint64_t off);
+uint64_t scap_ftell(scap_t* handle);
+void scap_fseek(scap_t* handle, uint64_t off);
 int32_t scap_fd_add(scap_threadinfo* tinfo, scap_fdinfo* fdinfo);
 
 int32_t scap_get_n_tracepoint_hit(scap_t* handle, long* ret);
