@@ -16,7 +16,8 @@ limitations under the License.
 
 */
 
-#if !defined(MINIMAL_BUILD) and !defined(__EMSCRIPTEN__) // MINIMAL_BUILD and emscripten don't support containers at all
+#if !defined(MINIMAL_BUILD) and \
+        !defined(__EMSCRIPTEN__)  // MINIMAL_BUILD and emscripten don't support containers at all
 #include <gtest/gtest.h>
 #include <libsinsp/container_engine/cri.h>
 #include <libsinsp/cri.hpp>
@@ -26,12 +27,13 @@ limitations under the License.
 /*
  * Mock container runtime socket API responses for both container and pod in the crio CRI scenario,
  * thereby enabling us to test the parser logic.
- * Since we're not querying the socket directly, calling higher-level parsing functions isn't feasible.
- * Instead, we perform targeted step-by-step tests that closely resemble the actual code flow.
+ * Since we're not querying the socket directly, calling higher-level parsing functions isn't
+ * feasible. Instead, we perform targeted step-by-step tests that closely resemble the actual code
+ * flow.
  *
- * Note: The container and pod status responses below are mocked and don't come from a real server, so
- * some information might need to be added later. You can use the crictl tool to obtain realistic JSONs
- * by inspecting the container and pod with their truncated IDs:
+ * Note: The container and pod status responses below are mocked and don't come from a real server,
+ * so some information might need to be added later. You can use the crictl tool to obtain realistic
+ * JSONs by inspecting the container and pod with their truncated IDs:
  *
  * https://github.com/kubernetes-sigs/cri-tools/blob/master/docs/crictl.md
  *
@@ -401,9 +403,7 @@ std::string pod_info_json_crio = R"({
   }
 })";
 
-runtime::v1alpha2::ContainerStatusResponse get_default_cri_crio_container_status_resp()
-{
-
+runtime::v1alpha2::ContainerStatusResponse get_default_cri_crio_container_status_resp() {
 	// "status": {
 	//     "id": "49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad",
 	//     "metadata": {
@@ -419,7 +419,8 @@ runtime::v1alpha2::ContainerStatusResponse get_default_cri_crio_container_status
 	//       "annotations": {},
 	//       "image": "quay.io/crio/redis:alpine"
 	//     },
-	//     "imageRef": "quay.io/crio/redis@sha256:1780b5a5496189974b94eb2595d86731d7a0820e4beb8ea770974298a943ed55",
+	//     "imageRef":
+	//     "quay.io/crio/redis@sha256:1780b5a5496189974b94eb2595d86731d7a0820e4beb8ea770974298a943ed55",
 	//     "reason": "",
 	//     "message": "",
 	//     "labels": {
@@ -448,7 +449,8 @@ runtime::v1alpha2::ContainerStatusResponse get_default_cri_crio_container_status
 	//         "selinuxRelabel": false,
 	//       }
 	//     ],
-	//     "logPath": "/var/log/crio/pods/1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca/49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.log"
+	//     "logPath":
+	//     "/var/log/crio/pods/1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca/49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.log"
 	//   },
 
 	// Mock container runtime socket API responses ContainerStatusResponse
@@ -457,10 +459,12 @@ runtime::v1alpha2::ContainerStatusResponse get_default_cri_crio_container_status
 
 	auto status = resp.mutable_status();
 	status->set_id("49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
-	status->set_state(runtime::v1alpha2::ContainerState::CONTAINER_RUNNING); // "CONTAINER_RUNNING"
-	status->set_created_at((uint64_t)1676262698000004577); // dummy
-	status->set_started_at((uint64_t)1676262698000004577); // dummy
-	status->set_image_ref("quay.io/crio/redis@sha256:1780b5a5496189974b94eb2595d86731d7a0820e4beb8ea770974298a943ed55");
+	status->set_state(runtime::v1alpha2::ContainerState::CONTAINER_RUNNING);  // "CONTAINER_RUNNING"
+	status->set_created_at((uint64_t)1676262698000004577);                    // dummy
+	status->set_started_at((uint64_t)1676262698000004577);                    // dummy
+	status->set_image_ref(
+	        "quay.io/crio/"
+	        "redis@sha256:1780b5a5496189974b94eb2595d86731d7a0820e4beb8ea770974298a943ed55");
 	status->mutable_image()->set_image("quay.io/crio/redis:alpine");
 	auto labels = status->mutable_labels();
 	(*labels)["io.kubernetes.container.name"] = "redis";
@@ -485,9 +489,7 @@ runtime::v1alpha2::ContainerStatusResponse get_default_cri_crio_container_status
 	return resp;
 }
 
-runtime::v1alpha2::PodSandboxStatusResponse get_default_cri_crio_pod_status_resp()
-{
-
+runtime::v1alpha2::PodSandboxStatusResponse get_default_cri_crio_pod_status_resp() {
 	//     "status": {
 	//     "id": "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca",
 	//     "metadata": {
@@ -532,7 +534,7 @@ runtime::v1alpha2::PodSandboxStatusResponse get_default_cri_crio_pod_status_resp
 	auto status = resp.mutable_status();
 	status->set_id("1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
 	status->set_state(runtime::v1alpha2::PodSandboxState::SANDBOX_READY);
-    status->set_created_at((uint64_t)1676262698000004577); // dummy
+	status->set_created_at((uint64_t)1676262698000004577);  // dummy
 	status->mutable_metadata()->set_name("podsandbox1");
 	status->mutable_network()->set_ip("10.244.0.3");
 	auto labels = status->mutable_labels();
@@ -554,22 +556,26 @@ runtime::v1alpha2::PodSandboxStatusResponse get_default_cri_crio_pod_status_resp
 	return resp;
 }
 
-TEST_F(sinsp_with_test_input, container_parser_cri_crio)
-{
+TEST_F(sinsp_with_test_input, container_parser_cri_crio) {
 	std::string cri_path = "/run/crio/crio_mock.sock";
 	auto cri_api_v1alpha2 = std::make_unique<libsinsp::cri::cri_interface_v1alpha2>(cri_path);
-	ASSERT_FALSE(cri_api_v1alpha2->is_ok()); // we are not querying a container runtime socket in this mock test
+	ASSERT_FALSE(
+	        cri_api_v1alpha2
+	                ->is_ok());  // we are not querying a container runtime socket in this mock test
 
 	// Get mock responses
-	runtime::v1alpha2::ContainerStatusResponse container_status_resp = get_default_cri_crio_container_status_resp();
-	runtime::v1alpha2::PodSandboxStatusResponse pod_sandbox_status_resp = get_default_cri_crio_pod_status_resp();
+	runtime::v1alpha2::ContainerStatusResponse container_status_resp =
+	        get_default_cri_crio_container_status_resp();
+	runtime::v1alpha2::PodSandboxStatusResponse pod_sandbox_status_resp =
+	        get_default_cri_crio_pod_status_resp();
 
 	const auto &resp_container = container_status_resp.status();
 	const auto &resp_container_info = container_status_resp.info();
 	const auto root_container = cri_api_v1alpha2->get_info_jvalue(resp_container_info);
 	const auto &resp_pod_sandbox_container = pod_sandbox_status_resp.status();
 	const auto &resp_pod_sandbox_container_info = pod_sandbox_status_resp.info();
-	const auto root_pod_sandbox = cri_api_v1alpha2->get_info_jvalue(resp_pod_sandbox_container_info);
+	const auto root_pod_sandbox =
+	        cri_api_v1alpha2->get_info_jvalue(resp_pod_sandbox_container_info);
 	std::shared_ptr<sinsp_container_info> container_ptr = std::make_shared<sinsp_container_info>();
 	// explicit reference to mimic actual code flow and test sub parser functions
 	sinsp_container_info &container = *container_ptr;
@@ -579,7 +585,7 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio)
 	//
 
 	container.m_type = CT_CRIO;
-	container.m_id = "49ecc2820215"; // truncated id extracted from cgroups
+	container.m_id = "49ecc2820215";  // truncated id extracted from cgroups
 	auto res = cri_api_v1alpha2->parse_cri_base(resp_container, container);
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_pod_sandbox_id_for_container(root_container, container);
@@ -588,28 +594,32 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio)
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_image(resp_container, root_container, container);
 	ASSERT_TRUE(res);
-	ASSERT_EQ("49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad", container.m_full_id);
+	ASSERT_EQ("49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad",
+	          container.m_full_id);
 	ASSERT_EQ("quay.io/crio/redis:alpine", container.m_image);
 	ASSERT_EQ("quay.io/crio/redis", container.m_imagerepo);
 	ASSERT_EQ("alpine", container.m_imagetag);
 
 	// CRI image failure resilience test for cases where it may begin with sha256
 	auto status = container_status_resp.mutable_status();
-	status->set_image_ref("sha256:49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
+	status->set_image_ref(
+	        "sha256:49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
 	status->mutable_image()->set_image("");
 	const auto &resp_container_simulate_image_recovery = container_status_resp.status();
-	res = cri_api_v1alpha2->parse_cri_image(resp_container_simulate_image_recovery, root_container, container);
+	res = cri_api_v1alpha2->parse_cri_image(resp_container_simulate_image_recovery,
+	                                        root_container,
+	                                        container);
 	ASSERT_TRUE(res);
 	ASSERT_EQ("quay.io/crio/redis:alpine", container.m_image);
 	ASSERT_EQ("quay.io/crio/redis", container.m_imagerepo);
 	ASSERT_EQ("alpine", container.m_imagetag);
 	res = cri_api_v1alpha2->parse_cri_json_imageid(root_container, container);
-	ASSERT_FALSE(res); // parse_cri_json_imageid only supported for containerd
+	ASSERT_FALSE(res);  // parse_cri_json_imageid only supported for containerd
 
 	res = cri_api_v1alpha2->parse_cri_mounts(resp_container, container);
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_env(root_container, container);
-	ASSERT_FALSE(res); // seems broken or not supported for cri-o
+	ASSERT_FALSE(res);  // seems broken or not supported for cri-o
 	res = cri_api_v1alpha2->parse_cri_user_info(root_container, container);
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_ext_container_info(root_container, container);
@@ -618,14 +628,16 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio)
 	ASSERT_EQ(20000, container.m_cpu_quota);
 
 	// Below retrieved from PodSandboxStatusResponse
-	res = cri_api_v1alpha2->parse_cri_pod_sandbox_network(resp_pod_sandbox_container, root_pod_sandbox, container);
+	res = cri_api_v1alpha2->parse_cri_pod_sandbox_network(resp_pod_sandbox_container,
+	                                                      root_pod_sandbox,
+	                                                      container);
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_pod_sandbox_labels(resp_pod_sandbox_container, container);
 	ASSERT_TRUE(res);
 
-	// 
+	//
 	// Test sinsp filterchecks, similar to spawn_process_container test
-	// 
+	//
 
 	add_default_init_thread();
 	open_inspector();
@@ -635,33 +647,123 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio)
 	scap_const_sized_buffer empty_bytebuf = {.buf = nullptr, .size = 0};
 
 	std::vector<std::string> cgroups = {
-		"cpuset=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
-		"cpu=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
-		"blkio=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
-		"memory=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
-		"hugetlb=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope", 
-		"pids=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
-		"misc=/pod_123.slice/pod_123-456.slice/crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope"};
+	        "cpuset=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
+	        "cpu=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
+	        "blkio=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
+	        "memory=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
+	        "hugetlb=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
+	        "pids=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope",
+	        "misc=/pod_123.slice/pod_123-456.slice/"
+	        "crio-49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad.scope"};
 	std::string cgroupsv = test_utils::to_null_delimited(cgroups);
+	container.set_lookup_status(sinsp_container_lookup::state::SUCCESSFUL);
 	std::string container_json = m_inspector.m_container_manager.container_to_json(container);
 	add_event_advance_ts(increasing_ts(), parent_tid, PPME_SYSCALL_CLONE_20_E, 0);
-	add_event_advance_ts(increasing_ts(), parent_tid, PPME_SYSCALL_CLONE_20_X, 20, child_tid, "bash", empty_bytebuf, (uint64_t)1, (uint64_t)1, (uint64_t)0, "", (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)12088, (uint32_t)7208, (uint32_t)0, "bash", scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()}, (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID | PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS), (uint32_t)1000, (uint32_t)1000, (uint64_t)parent_tid, (uint64_t)parent_pid);
-	add_event_advance_ts(increasing_ts(), child_tid, PPME_SYSCALL_CLONE_20_X, 20, (uint64_t)0, "bash", empty_bytebuf, child_tid, child_pid, (uint64_t)1, "", (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)12088, (uint32_t)3764, (uint32_t)0, "bash", scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()}, (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID | PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS), (uint32_t)1000, (uint32_t)1000, (uint64_t)1, (uint64_t)1);
+	add_event_advance_ts(increasing_ts(),
+	                     parent_tid,
+	                     PPME_SYSCALL_CLONE_20_X,
+	                     20,
+	                     child_tid,
+	                     "bash",
+	                     empty_bytebuf,
+	                     (uint64_t)1,
+	                     (uint64_t)1,
+	                     (uint64_t)0,
+	                     "",
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint32_t)12088,
+	                     (uint32_t)7208,
+	                     (uint32_t)0,
+	                     "bash",
+	                     scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()},
+	                     (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID |
+	                                PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS),
+	                     (uint32_t)1000,
+	                     (uint32_t)1000,
+	                     (uint64_t)parent_tid,
+	                     (uint64_t)parent_pid);
+	add_event_advance_ts(increasing_ts(),
+	                     child_tid,
+	                     PPME_SYSCALL_CLONE_20_X,
+	                     20,
+	                     (uint64_t)0,
+	                     "bash",
+	                     empty_bytebuf,
+	                     child_tid,
+	                     child_pid,
+	                     (uint64_t)1,
+	                     "",
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint32_t)12088,
+	                     (uint32_t)3764,
+	                     (uint32_t)0,
+	                     "bash",
+	                     scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()},
+	                     (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID |
+	                                PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS),
+	                     (uint32_t)1000,
+	                     (uint32_t)1000,
+	                     (uint64_t)1,
+	                     (uint64_t)1);
 	add_event_advance_ts(increasing_ts(), -1, PPME_CONTAINER_JSON_2_E, 1, container_json.c_str());
 	add_event_advance_ts(increasing_ts(), child_tid, PPME_SYSCALL_EXECVE_19_E, 1, "/bin/test-exe");
-	evt = add_event_advance_ts(increasing_ts(), child_tid, PPME_SYSCALL_EXECVE_19_X, 27, (int64_t)0, "/bin/test-exe", empty_bytebuf, child_tid, child_pid, parent_tid, "", (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)29612, (uint32_t)4, (uint32_t)0, "test-exe", scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()}, empty_bytebuf, (int32_t)34818, parent_pid, (uint32_t)0, (int32_t)PPM_EXE_UPPER_LAYER, parent_pid, parent_pid, parent_pid, (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           child_tid,
+	                           PPME_SYSCALL_EXECVE_19_X,
+	                           27,
+	                           (int64_t)0,
+	                           "/bin/test-exe",
+	                           empty_bytebuf,
+	                           child_tid,
+	                           child_pid,
+	                           parent_tid,
+	                           "",
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint32_t)29612,
+	                           (uint32_t)4,
+	                           (uint32_t)0,
+	                           "test-exe",
+	                           scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()},
+	                           empty_bytebuf,
+	                           (int32_t)34818,
+	                           parent_pid,
+	                           (uint32_t)0,
+	                           (int32_t)PPM_EXE_UPPER_LAYER,
+	                           parent_pid,
+	                           parent_pid,
+	                           parent_pid,
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint32_t)0);
 
 	// Check containers were added to the container cache
-	const sinsp_container_info::ptr_t container_info_check = m_inspector.m_container_manager.get_container(container.m_id);
+	const sinsp_container_info::ptr_t container_info_check =
+	        m_inspector.m_container_manager.get_container(container.m_id);
 	ASSERT_TRUE(container_info_check);
 	ASSERT_EQ("49ecc2820215", container_info_check->m_id);
 
-	// Check container and k8s related filter fields that are retrieved from the container runtime socket
+	// Check container and k8s related filter fields that are retrieved from the container runtime
+	// socket
 	ASSERT_EQ(get_field_as_string(evt, "container.id"), "49ecc2820215");
-	ASSERT_EQ(get_field_as_string(evt, "container.full_id"), "49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
+	ASSERT_EQ(get_field_as_string(evt, "container.full_id"),
+	          "49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
 	ASSERT_EQ(get_field_as_string(evt, "container.name"), "redis");
 	ASSERT_EQ(get_field_as_string(evt, "container.image"), "quay.io/crio/redis:alpine");
-	// ASSERT_EQ(get_field_as_string(evt, "container.image.id"), "redis"); // TBD unsure how it's parsed in cri.hpp for cri-o
+	// ASSERT_EQ(get_field_as_string(evt, "container.image.id"), "redis"); // TBD unsure how it's
+	// parsed in cri.hpp for cri-o
 	ASSERT_EQ(get_field_as_string(evt, "container.type"), "cri-o");
 	ASSERT_EQ(get_field_as_string(evt, "container.privileged"), "true");
 	ASSERT_EQ(get_field_as_string(evt, "container.mounts"), "/boot:/host/boot::false:private");
@@ -670,39 +772,58 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio)
 	ASSERT_EQ(get_field_as_string(evt, "container.mount.propagation[/boot]"), "private");
 	ASSERT_EQ(get_field_as_string(evt, "container.image.repository"), "quay.io/crio/redis");
 	ASSERT_EQ(get_field_as_string(evt, "container.image.tag"), "alpine");
-	ASSERT_EQ(get_field_as_string(evt, "container.image.digest"), "sha256:49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
+	ASSERT_EQ(get_field_as_string(evt, "container.image.digest"),
+	          "sha256:49ecc282021562c567a8159ef424a06cdd8637efdca5953de9794eafe29adcad");
 	ASSERT_EQ(get_field_as_string(evt, "container.ip"), "10.244.0.3");
-	ASSERT_EQ(get_field_as_string(evt, "container.cni.json"), "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10.244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
+	ASSERT_EQ(get_field_as_string(evt, "container.cni.json"),
+	          "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:"
+	          "76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":"
+	          "\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/"
+	          "dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10."
+	          "244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/"
+	          "0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
 
 	ASSERT_EQ(get_field_as_string(evt, "k8s.ns.name"), "redhat.test.crio");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.name"), "podsandbox1");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.id"), "redhat-test-crio"); // legacy pod UID
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.uid"), get_field_as_string(evt, "k8s.pod.id")); // new semantically correct pod UID
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.id"), "redhat-test-crio");  // legacy pod UID
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.uid"),
+	          get_field_as_string(evt, "k8s.pod.id"));  // new semantically correct pod UID
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.sandbox_id"), "1f04600dc694");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.full_sandbox_id"), "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.full_sandbox_id"),
+	          "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.label.example-label/custom_one"), "mylabel");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.label[example-label/custom_one]"), "mylabel");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.labels"), "app:myapp, example-label/custom_one:mylabel");
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.labels"),
+	          "app:myapp, example-label/custom_one:mylabel");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.ip"), "10.244.0.3");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.cni.json"), "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10.244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.cni.json"),
+	          "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:"
+	          "76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":"
+	          "\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/"
+	          "dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10."
+	          "244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/"
+	          "0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
 }
 
-TEST_F(sinsp_with_test_input, container_parser_cri_crio_sandbox_container)
-{
+TEST_F(sinsp_with_test_input, container_parser_cri_crio_sandbox_container) {
 	//
 	// On ther other hand this test is solely for sandbox container processes
 	//
 
 	std::string cri_path = "/run/crio/crio_mock.sock";
 	auto cri_api_v1alpha2 = std::make_unique<libsinsp::cri::cri_interface_v1alpha2>(cri_path);
-	ASSERT_FALSE(cri_api_v1alpha2->is_ok()); // we are not querying a container runtime socket in this mock test
+	ASSERT_FALSE(
+	        cri_api_v1alpha2
+	                ->is_ok());  // we are not querying a container runtime socket in this mock test
 
 	// Get mock responses
-	runtime::v1alpha2::PodSandboxStatusResponse pod_sandbox_status_resp = get_default_cri_crio_pod_status_resp();
+	runtime::v1alpha2::PodSandboxStatusResponse pod_sandbox_status_resp =
+	        get_default_cri_crio_pod_status_resp();
 
 	const auto &resp_pod_sandbox_container = pod_sandbox_status_resp.status();
 	const auto &resp_pod_sandbox_container_info = pod_sandbox_status_resp.info();
-	const auto root_pod_sandbox = cri_api_v1alpha2->get_info_jvalue(resp_pod_sandbox_container_info);
+	const auto root_pod_sandbox =
+	        cri_api_v1alpha2->get_info_jvalue(resp_pod_sandbox_container_info);
 	std::shared_ptr<sinsp_container_info> container_ptr = std::make_shared<sinsp_container_info>();
 	sinsp_container_info &container = *container_ptr;
 
@@ -711,7 +832,8 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio_sandbox_container)
 	//
 
 	container.m_type = CT_CONTAINERD;
-	container.m_id = "1f04600dc694"; // truncated id extracted from cgroups for the sandbox container
+	container.m_id =
+	        "1f04600dc694";  // truncated id extracted from cgroups for the sandbox container
 	container.m_is_pod_sandbox = true;
 	auto res = cri_api_v1alpha2->parse_cri_base(resp_pod_sandbox_container, container);
 	ASSERT_TRUE(res);
@@ -719,15 +841,17 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio_sandbox_container)
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_labels(resp_pod_sandbox_container, container);
 	ASSERT_TRUE(res);
-	res = cri_api_v1alpha2->parse_cri_pod_sandbox_network(resp_pod_sandbox_container, root_pod_sandbox, container);
+	res = cri_api_v1alpha2->parse_cri_pod_sandbox_network(resp_pod_sandbox_container,
+	                                                      root_pod_sandbox,
+	                                                      container);
 	ASSERT_TRUE(res);
 	res = cri_api_v1alpha2->parse_cri_pod_sandbox_labels(resp_pod_sandbox_container, container);
 	ASSERT_TRUE(res);
 	ASSERT_TRUE(container.m_is_pod_sandbox);
 
-	// 
+	//
 	// Test sinsp filterchecks, similar to spawn_process_container test
-	// 
+	//
 
 	add_default_init_thread();
 	open_inspector();
@@ -737,46 +861,152 @@ TEST_F(sinsp_with_test_input, container_parser_cri_crio_sandbox_container)
 	scap_const_sized_buffer empty_bytebuf = {.buf = nullptr, .size = 0};
 
 	std::vector<std::string> cgroups = {
-		"cpuset=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
-		"cpu=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
-		"blkio=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
-		"memory=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
-		"hugetlb=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope", 
-		"pids=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
-		"misc=/pod_123.slice/pod_123-456.slice/crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope"};
+	        "cpuset=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
+	        "cpu=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
+	        "blkio=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
+	        "memory=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
+	        "hugetlb=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
+	        "pids=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope",
+	        "misc=/pod_123.slice/pod_123-456.slice/"
+	        "crio-1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca.scope"};
 	std::string cgroupsv = test_utils::to_null_delimited(cgroups);
+	container.set_lookup_status(sinsp_container_lookup::state::SUCCESSFUL);
 	std::string container_json = m_inspector.m_container_manager.container_to_json(container);
 	add_event_advance_ts(increasing_ts(), parent_tid, PPME_SYSCALL_CLONE_20_E, 0);
-	add_event_advance_ts(increasing_ts(), parent_tid, PPME_SYSCALL_CLONE_20_X, 20, child_tid, "bash", empty_bytebuf, (uint64_t)1, (uint64_t)1, (uint64_t)0, "", (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)12088, (uint32_t)7208, (uint32_t)0, "bash", scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()}, (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID | PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS), (uint32_t)1000, (uint32_t)1000, (uint64_t)parent_tid, (uint64_t)parent_pid);
-	add_event_advance_ts(increasing_ts(), child_tid, PPME_SYSCALL_CLONE_20_X, 20, (uint64_t)0, "bash", empty_bytebuf, child_tid, child_pid, (uint64_t)1, "", (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)12088, (uint32_t)3764, (uint32_t)0, "bash", scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()}, (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID | PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS), (uint32_t)1000, (uint32_t)1000, (uint64_t)1, (uint64_t)1);
+	add_event_advance_ts(increasing_ts(),
+	                     parent_tid,
+	                     PPME_SYSCALL_CLONE_20_X,
+	                     20,
+	                     child_tid,
+	                     "bash",
+	                     empty_bytebuf,
+	                     (uint64_t)1,
+	                     (uint64_t)1,
+	                     (uint64_t)0,
+	                     "",
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint32_t)12088,
+	                     (uint32_t)7208,
+	                     (uint32_t)0,
+	                     "bash",
+	                     scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()},
+	                     (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID |
+	                                PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS),
+	                     (uint32_t)1000,
+	                     (uint32_t)1000,
+	                     (uint64_t)parent_tid,
+	                     (uint64_t)parent_pid);
+	add_event_advance_ts(increasing_ts(),
+	                     child_tid,
+	                     PPME_SYSCALL_CLONE_20_X,
+	                     20,
+	                     (uint64_t)0,
+	                     "bash",
+	                     empty_bytebuf,
+	                     child_tid,
+	                     child_pid,
+	                     (uint64_t)1,
+	                     "",
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint64_t)0,
+	                     (uint32_t)12088,
+	                     (uint32_t)3764,
+	                     (uint32_t)0,
+	                     "bash",
+	                     scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()},
+	                     (uint32_t)(PPM_CL_CLONE_CHILD_CLEARTID | PPM_CL_CLONE_CHILD_SETTID |
+	                                PPM_CL_CLONE_NEWPID | PPM_CL_CHILD_IN_PIDNS),
+	                     (uint32_t)1000,
+	                     (uint32_t)1000,
+	                     (uint64_t)1,
+	                     (uint64_t)1);
 	add_event_advance_ts(increasing_ts(), -1, PPME_CONTAINER_JSON_2_E, 1, container_json.c_str());
 	add_event_advance_ts(increasing_ts(), child_tid, PPME_SYSCALL_EXECVE_19_E, 1, "/bin/test-exe");
-	evt = add_event_advance_ts(increasing_ts(), child_tid, PPME_SYSCALL_EXECVE_19_X, 27, (int64_t)0, "/bin/test-exe", empty_bytebuf, child_tid, child_pid, parent_tid, "", (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)29612, (uint32_t)4, (uint32_t)0, "test-exe", scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()}, empty_bytebuf, (int32_t)34818, parent_pid, (uint32_t)0, (int32_t)PPM_EXE_UPPER_LAYER, parent_pid, parent_pid, parent_pid, (uint64_t)0, (uint64_t)0, (uint64_t)0, (uint32_t)0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           child_tid,
+	                           PPME_SYSCALL_EXECVE_19_X,
+	                           27,
+	                           (int64_t)0,
+	                           "/bin/test-exe",
+	                           empty_bytebuf,
+	                           child_tid,
+	                           child_pid,
+	                           parent_tid,
+	                           "",
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint32_t)29612,
+	                           (uint32_t)4,
+	                           (uint32_t)0,
+	                           "test-exe",
+	                           scap_const_sized_buffer{cgroupsv.data(), cgroupsv.size()},
+	                           empty_bytebuf,
+	                           (int32_t)34818,
+	                           parent_pid,
+	                           (uint32_t)0,
+	                           (int32_t)PPM_EXE_UPPER_LAYER,
+	                           parent_pid,
+	                           parent_pid,
+	                           parent_pid,
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint64_t)0,
+	                           (uint32_t)0);
 
 	// Check containers were added to the container cache
-	const sinsp_container_info::ptr_t container_info_check = m_inspector.m_container_manager.get_container(container.m_id);
+	const sinsp_container_info::ptr_t container_info_check =
+	        m_inspector.m_container_manager.get_container(container.m_id);
 	ASSERT_TRUE(container_info_check);
 	ASSERT_EQ("1f04600dc694", container_info_check->m_id);
 
-	// Check container and k8s related filter fields that are retrieved from the container runtime socket
+	// Check container and k8s related filter fields that are retrieved from the container runtime
+	// socket
 	ASSERT_EQ(get_field_as_string(evt, "container.id"), "1f04600dc694");
-	ASSERT_EQ(get_field_as_string(evt, "container.full_id"), "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
+	ASSERT_EQ(get_field_as_string(evt, "container.full_id"),
+	          "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
 	ASSERT_EQ(get_field_as_string(evt, "container.ip"), "10.244.0.3");
-	ASSERT_EQ(get_field_as_string(evt, "container.cni.json"), "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10.244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
+	ASSERT_EQ(get_field_as_string(evt, "container.cni.json"),
+	          "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:"
+	          "76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":"
+	          "\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/"
+	          "dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10."
+	          "244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/"
+	          "0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
 
 	ASSERT_EQ(get_field_as_string(evt, "k8s.ns.name"), "redhat.test.crio");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.name"), "podsandbox1");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.id"), "redhat-test-crio"); // legacy pod UID
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.uid"), get_field_as_string(evt, "k8s.pod.id")); // new semantically correct pod UID
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.id"), "redhat-test-crio");  // legacy pod UID
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.uid"),
+	          get_field_as_string(evt, "k8s.pod.id"));  // new semantically correct pod UID
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.sandbox_id"), "1f04600dc694");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.full_sandbox_id"), "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.full_sandbox_id"),
+	          "1f04600dc6949359da68eee5fe7c4069706a567c07d1ef89fe3bbfdeac7a6dca");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.label.example-label/custom_one"), "mylabel");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.label[example-label/custom_one]"), "mylabel");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.labels"), "app:myapp, example-label/custom_one:mylabel");
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.labels"),
+	          "app:myapp, example-label/custom_one:mylabel");
 	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.ip"), "10.244.0.3");
-	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.cni.json"), "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10.244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
+	ASSERT_EQ(get_field_as_string(evt, "k8s.pod.cni.json"),
+	          "{\"cniVersion\":\"1.0.0\",\"interfaces\":[{\"name\":\"bridge\",\"mac\":\"ce:64:08:"
+	          "76:88:6a\"},{\"name\":\"veth71b0e931\",\"mac\":\"72:b7:4f:bc:e4:a4\"},{\"name\":"
+	          "\"eth0\",\"mac\":\"fe:06:00:f8:2f:4d\",\"sandbox\":\"/var/run/netns/"
+	          "dec735d1-0e86-44c1-94e0-a102173334a4\"}],\"ips\":[{\"interface\":2,\"address\":\"10."
+	          "244.0.3/16\",\"gateway\":\"10.244.0.1\"}],\"routes\":[{\"dst\":\"0.0.0.0/"
+	          "0\",\"gw\":\"10.244.0.1\"}],\"dns\":{}}");
 
-	// Since this is a pod sandbox container, making it clear that container ID and sandbox ID are the same
-	ASSERT_EQ(get_field_as_string(evt, "container.id"), get_field_as_string(evt, "k8s.pod.sandbox_id"));
+	// Since this is a pod sandbox container, making it clear that container ID and sandbox ID are
+	// the same
+	ASSERT_EQ(get_field_as_string(evt, "container.id"),
+	          get_field_as_string(evt, "k8s.pod.sandbox_id"));
 }
-#endif // MINIMAL_BUILD
+#endif  // MINIMAL_BUILD
