@@ -23,7 +23,7 @@ limitations under the License.
 #include <arpa/inet.h>
 #include <netinet/in.h>
 
-#define ASSERT_FD_FILTER_CHECK_NOT_FILE()                                \
+#define ASSERT_FD_FILTER_CHECK_NOT_FILE()                            \
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "");              \
 	ASSERT_EQ(get_field_as_string(evt, "fd.l4proto"), "<NA>");       \
 	ASSERT_EQ(get_field_as_string(evt, "fd.is_server"), "false");    \
@@ -35,7 +35,7 @@ limitations under the License.
 	ASSERT_EQ(get_field_as_string(evt, "fd.dev.minor"), "0");        \
 	ASSERT_EQ(get_field_as_string(evt, "fd.nameraw"), "");
 
-#define ASSERT_FD_GETTERS_NOT_FILE(x)        \
+#define ASSERT_FD_GETTERS_NOT_FILE(x)    \
 	ASSERT_EQ(x->m_name, "");            \
 	ASSERT_EQ(x->m_name_raw, "");        \
 	ASSERT_EQ(x->m_oldname, "");         \
@@ -51,8 +51,7 @@ limitations under the License.
 	ASSERT_FALSE(x->is_file());          \
 	ASSERT_FALSE(x->is_directory());
 
-TEST_F(sinsp_with_test_input, file_open)
-{
+TEST_F(sinsp_with_test_input, file_open) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -60,8 +59,23 @@ TEST_F(sinsp_with_test_input, file_open)
 
 	// since adding and reading events happens on a single thread they can be interleaved.
 	// tests may need to change if that will not be the case anymore
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_E, 3, "/tmp/the_file", (uint32_t) PPM_O_RDWR, (uint32_t) 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_X, 6, (uint64_t)3, "/tmp/the_file", (uint32_t) PPM_O_RDWR, (uint32_t) 0, (uint32_t) 5, (uint64_t)123);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     "/tmp/the_file",
+	                     (uint32_t)PPM_O_RDWR,
+	                     (uint32_t)0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_X,
+	                           6,
+	                           (uint64_t)3,
+	                           "/tmp/the_file",
+	                           (uint32_t)PPM_O_RDWR,
+	                           (uint32_t)0,
+	                           (uint32_t)5,
+	                           (uint64_t)123);
 
 	ASSERT_EQ(evt->get_type(), PPME_SYSCALL_OPEN_X);
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/tmp/the_file");
@@ -69,8 +83,7 @@ TEST_F(sinsp_with_test_input, file_open)
 	ASSERT_EQ(get_field_as_string(evt, "fd.filename"), "the_file");
 }
 
-TEST_F(sinsp_with_test_input, dup_dup2_dup3)
-{
+TEST_F(sinsp_with_test_input, dup_dup2_dup3) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -78,8 +91,23 @@ TEST_F(sinsp_with_test_input, dup_dup2_dup3)
 
 	int64_t fd = 3, res = 1, oldfd = 3, newfd = 123;
 
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_E, 3, "/tmp/test", (uint32_t) (PPM_O_TRUNC | PPM_O_CREAT | PPM_O_WRONLY), (uint32_t) 0666);
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_X, 6, fd, "/tmp/test", (uint32_t) (PPM_O_TRUNC | PPM_O_CREAT | PPM_O_WRONLY), (uint32_t) 0666, (uint32_t) 0xCA02, (uint64_t)123);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     "/tmp/test",
+	                     (uint32_t)(PPM_O_TRUNC | PPM_O_CREAT | PPM_O_WRONLY),
+	                     (uint32_t)0666);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_OPEN_X,
+	                     6,
+	                     fd,
+	                     "/tmp/test",
+	                     (uint32_t)(PPM_O_TRUNC | PPM_O_CREAT | PPM_O_WRONLY),
+	                     (uint32_t)0666,
+	                     (uint32_t)0xCA02,
+	                     (uint64_t)123);
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_DUP_E, 1, fd);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_DUP_X, 1, newfd);
@@ -107,8 +135,7 @@ TEST_F(sinsp_with_test_input, dup_dup2_dup3)
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "1");
 }
 
-TEST_F(sinsp_with_test_input, open_by_handle_at)
-{
+TEST_F(sinsp_with_test_input, open_by_handle_at) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -117,7 +144,14 @@ TEST_F(sinsp_with_test_input, open_by_handle_at)
 	int64_t fd = 4, mountfd = 5;
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_BY_HANDLE_AT_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_BY_HANDLE_AT_X, 4, fd, mountfd, PPM_O_RDWR, "/tmp/the_file.txt");
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_BY_HANDLE_AT_X,
+	                           4,
+	                           fd,
+	                           mountfd,
+	                           PPM_O_RDWR,
+	                           "/tmp/the_file.txt");
 
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/tmp/the_file.txt");
 	ASSERT_EQ(get_field_as_string(evt, "evt.abspath"), "/tmp/the_file.txt");
@@ -125,13 +159,19 @@ TEST_F(sinsp_with_test_input, open_by_handle_at)
 	fd = 6;
 	mountfd = 7;
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_BY_HANDLE_AT_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_BY_HANDLE_AT_X, 4, fd, mountfd, PPM_O_RDWR, "<NA>");
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_BY_HANDLE_AT_X,
+	                           4,
+	                           fd,
+	                           mountfd,
+	                           PPM_O_RDWR,
+	                           "<NA>");
 
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "<NA>");
 }
 
-TEST_F(sinsp_with_test_input, path_too_long)
-{
+TEST_F(sinsp_with_test_input, path_too_long) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -150,27 +190,54 @@ TEST_F(sinsp_with_test_input, path_too_long)
 	std::string long_path = long_path_ss.str();
 	int64_t fd = 3, mountfd = 5;
 
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_E, 3, long_path.c_str(), (uint32_t) PPM_O_RDWR, (uint32_t) 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_X, 6, fd, long_path.c_str(), (uint32_t) PPM_O_RDWR, (uint32_t) 0, (uint32_t) 5, (uint64_t)123);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     long_path.c_str(),
+	                     (uint32_t)PPM_O_RDWR,
+	                     (uint32_t)0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_X,
+	                           6,
+	                           fd,
+	                           long_path.c_str(),
+	                           (uint32_t)PPM_O_RDWR,
+	                           (uint32_t)0,
+	                           (uint32_t)5,
+	                           (uint64_t)123);
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/PATH_TOO_LONG");
 
 	fd = 4;
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_BY_HANDLE_AT_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_BY_HANDLE_AT_X, 4, fd, mountfd, PPM_O_RDWR, long_path.c_str());
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_BY_HANDLE_AT_X,
+	                           4,
+	                           fd,
+	                           mountfd,
+	                           PPM_O_RDWR,
+	                           long_path.c_str());
 
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/PATH_TOO_LONG");
 	ASSERT_EQ(get_field_as_string(evt, "evt.abspath"), "/PATH_TOO_LONG");
 }
 
-TEST_F(sinsp_with_test_input, creates_fd_generic)
-{
+TEST_F(sinsp_with_test_input, creates_fd_generic) {
 	add_default_init_thread();
 
 	open_inspector();
 	sinsp_evt* evt = NULL;
 
 	int64_t fd = 5;
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_SIGNALFD_E, 3, (uint64_t)-1, NULL, 0);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_SIGNALFD_E,
+	                     3,
+	                     (uint64_t)-1,
+	                     0,
+	                     (uint8_t)0);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_SIGNALFD_X, 1, fd);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "signalfd");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "s");
@@ -184,14 +251,19 @@ TEST_F(sinsp_with_test_input, creates_fd_generic)
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "2");
 
 	fd = 6;
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_TIMERFD_CREATE_E, 2, 0, 0);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_TIMERFD_CREATE_E,
+	                     2,
+	                     (uint8_t)0,
+	                     (uint8_t)0);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_TIMERFD_CREATE_X, 1, fd);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "timerfd");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "t");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "6");
 
 	fd = 7;
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_INOTIFY_INIT_E, 1, 0);
+	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_INOTIFY_INIT_E, 1, (uint8_t)0);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_INOTIFY_INIT_X, 1, fd);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "inotify");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "i");
@@ -213,7 +285,18 @@ TEST_F(sinsp_with_test_input, creates_fd_generic)
 
 	fd = 10;
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_IO_URING_SETUP_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_IO_URING_SETUP_X, 8, fd, 0, 0, 0, 0, 0, 0, 0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_IO_URING_SETUP_X,
+	                           8,
+	                           fd,
+	                           0,
+	                           0,
+	                           0,
+	                           0,
+	                           0,
+	                           0,
+	                           0);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "io_uring");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "r");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "10");
@@ -234,38 +317,62 @@ TEST_F(sinsp_with_test_input, creates_fd_generic)
 
 	int64_t fd1 = 3, fd2 = 4;
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE_X, 4, (int64_t) 0, fd1, fd2, (uint64_t)81976492);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_PIPE_X,
+	                           4,
+	                           (int64_t)0,
+	                           fd1,
+	                           fd2,
+	                           (uint64_t)81976492);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "pipe");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "p");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "4");
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE2_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE2_X, 5, (int64_t) 0, (int64_t)6, (int64_t)7, (uint64_t)81976492, (uint32_t)17);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_PIPE2_X,
+	                           5,
+	                           (int64_t)0,
+	                           (int64_t)6,
+	                           (int64_t)7,
+	                           (uint64_t)81976492,
+	                           (uint32_t)17);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "pipe");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "p");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "7");
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_INOTIFY_INIT1_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_INOTIFY_INIT1_X, 2, (int64_t)12, (uint16_t)32);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_INOTIFY_INIT1_X,
+	                           2,
+	                           (int64_t)12,
+	                           (uint16_t)32);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "inotify");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "i");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "12");
 
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_EVENTFD_E, 2, (uint64_t)0, (uint16_t)45);
+	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_EVENTFD_E, 2, (uint64_t)0, (uint32_t)45);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_EVENTFD_X, 1, (int64_t)34);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "event");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "e");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "34");
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_EVENTFD2_E, 1, (uint64_t)0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_EVENTFD2_X, 2, (int64_t)31, (uint16_t)34);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_EVENTFD2_X,
+	                           2,
+	                           (int64_t)31,
+	                           (uint16_t)34);
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "event");
 	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "e");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "31");
 }
 
-TEST_F(sinsp_with_test_input, umount)
-{
+TEST_F(sinsp_with_test_input, umount) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -284,8 +391,7 @@ TEST_F(sinsp_with_test_input, umount)
 	ASSERT_EQ(fdinfo, nullptr);
 }
 
-TEST_F(sinsp_with_test_input, umount2)
-{
+TEST_F(sinsp_with_test_input, umount2) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -305,8 +411,7 @@ TEST_F(sinsp_with_test_input, umount2)
 	ASSERT_EQ(fdinfo, nullptr);
 }
 
-TEST_F(sinsp_with_test_input, pipe)
-{
+TEST_F(sinsp_with_test_input, pipe) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -318,9 +423,10 @@ TEST_F(sinsp_with_test_input, pipe)
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE_E, 0);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE_X, 4, res, fd1, fd2, ino);
 
-	/* `pipe` is particular because it generates 2 file descriptors but a single event can have at most one `fdinfo` associated.
-	 * So in this case the associated file descriptor is the second one (`4`). Please note that both file descriptors are added to
-	 * thread info, but in the `m_fdinfo` field we find only the second file descriptor.
+	/* `pipe` is particular because it generates 2 file descriptors but a single event can have at
+	 * most one `fdinfo` associated. So in this case the associated file descriptor is the second
+	 * one (`4`). Please note that both file descriptors are added to thread info, but in the
+	 * `m_fdinfo` field we find only the second file descriptor.
 	 */
 
 	/* Here we assert some info regarding the second file descriptor `4` through filter-checks */
@@ -338,7 +444,8 @@ TEST_F(sinsp_with_test_input, pipe)
 	ASSERT_EQ(fdinfo2->m_openflags, 0);
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo2)
 
-	/* Now we get the first file descriptor (`3`) and we assert some fields directly through the `fdinfo` pointer. */
+	/* Now we get the first file descriptor (`3`) and we assert some fields directly through the
+	 * `fdinfo` pointer. */
 
 	ASSERT_NE(evt->get_thread_info(), nullptr);
 	sinsp_fdinfo* fdinfo1 = evt->get_thread_info()->get_fd(fd1);
@@ -351,8 +458,7 @@ TEST_F(sinsp_with_test_input, pipe)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo1)
 }
 
-TEST_F(sinsp_with_test_input, pipe2)
-{
+TEST_F(sinsp_with_test_input, pipe2) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -363,11 +469,20 @@ TEST_F(sinsp_with_test_input, pipe2)
 	uint32_t flags = 17;
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE2_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIPE2_X, 5, res, fd1, fd2, ino, flags);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_PIPE2_X,
+	                           5,
+	                           res,
+	                           fd1,
+	                           fd2,
+	                           ino,
+	                           flags);
 
-	/* `pipe2` is particular because it generates 2 file descriptors but a single event can have at most one `fdinfo` associated.
-	 * So in this case the associated file descriptor is the second one (`4`). Please note that both file descriptors are added to
-	 * thread info, but in the `m_fdinfo` field we find only the second file descriptor.
+	/* `pipe2` is particular because it generates 2 file descriptors but a single event can have at
+	 * most one `fdinfo` associated. So in this case the associated file descriptor is the second
+	 * one (`4`). Please note that both file descriptors are added to thread info, but in the
+	 * `m_fdinfo` field we find only the second file descriptor.
 	 */
 
 	/* Here we assert some info regarding the second file descriptor `6` through filter-checks */
@@ -379,13 +494,15 @@ TEST_F(sinsp_with_test_input, pipe2)
 	ASSERT_EQ(get_field_as_string(evt, "fd.ino"), std::to_string(ino));
 	ASSERT_FD_FILTER_CHECK_NOT_FILE()
 
-	/* Here we check the `openflags` field of the fdinfo2, it should be 17 since pipe2 has flags field */
+	/* Here we check the `openflags` field of the fdinfo2, it should be 17 since pipe2 has flags
+	 * field */
 	sinsp_fdinfo* fdinfo2 = evt->get_fd_info();
 	ASSERT_NE(fdinfo2, nullptr);
 	ASSERT_EQ(fdinfo2->m_openflags, flags);
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo2)
 
-	/* Now we get the first file descriptor (`3`) and we assert some fields directly through the `fdinfo` pointer. */
+	/* Now we get the first file descriptor (`3`) and we assert some fields directly through the
+	 * `fdinfo` pointer. */
 	ASSERT_NE(evt->get_thread_info(), nullptr);
 	sinsp_fdinfo* fdinfo1 = evt->get_thread_info()->get_fd(fd1);
 	ASSERT_NE(fdinfo1, nullptr);
@@ -397,8 +514,7 @@ TEST_F(sinsp_with_test_input, pipe2)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo1)
 }
 
-TEST_F(sinsp_with_test_input, inotify_init)
-{
+TEST_F(sinsp_with_test_input, inotify_init) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -426,8 +542,7 @@ TEST_F(sinsp_with_test_input, inotify_init)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo)
 }
 
-TEST_F(sinsp_with_test_input, inotify_init1)
-{
+TEST_F(sinsp_with_test_input, inotify_init1) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -454,13 +569,12 @@ TEST_F(sinsp_with_test_input, inotify_init1)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo)
 }
 
-TEST_F(sinsp_with_test_input, eventfd)
-{
+TEST_F(sinsp_with_test_input, eventfd) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
 	int64_t res = 21;
-	uint16_t flags = 6;
+	uint32_t flags = 6;
 	uint64_t initval = 0;
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_EVENTFD_E, 2, initval, flags);
@@ -484,8 +598,7 @@ TEST_F(sinsp_with_test_input, eventfd)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo)
 }
 
-TEST_F(sinsp_with_test_input, eventfd2)
-{
+TEST_F(sinsp_with_test_input, eventfd2) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -513,8 +626,7 @@ TEST_F(sinsp_with_test_input, eventfd2)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo)
 }
 
-TEST_F(sinsp_with_test_input, signalfd)
-{
+TEST_F(sinsp_with_test_input, signalfd) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -543,8 +655,7 @@ TEST_F(sinsp_with_test_input, signalfd)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo)
 }
 
-TEST_F(sinsp_with_test_input, signalfd4)
-{
+TEST_F(sinsp_with_test_input, signalfd4) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -573,12 +684,11 @@ TEST_F(sinsp_with_test_input, signalfd4)
 	ASSERT_FD_GETTERS_NOT_FILE(fdinfo)
 }
 
-TEST_F(sinsp_with_test_input, fchmod)
-{
+TEST_F(sinsp_with_test_input, fchmod) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
-	const char *path = "/tmp/test";
+	const char* path = "/tmp/test";
 	int64_t fd = 3;
 	int32_t flags = PPM_O_RDWR;
 	uint32_t mode = 0;
@@ -589,7 +699,16 @@ TEST_F(sinsp_with_test_input, fchmod)
 
 	// We need to open a fd first so fchmod can act on it
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_X, 6, fd, path, flags, mode, dev, ino);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_X,
+	                           6,
+	                           fd,
+	                           path,
+	                           flags,
+	                           mode,
+	                           dev,
+	                           ino);
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/tmp/test");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "3");
 
@@ -599,12 +718,11 @@ TEST_F(sinsp_with_test_input, fchmod)
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "3");
 }
 
-TEST_F(sinsp_with_test_input, fchown)
-{
+TEST_F(sinsp_with_test_input, fchown) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
-	const char *path = "/tmp/test";
+	const char* path = "/tmp/test";
 	int64_t fd = 3;
 	int32_t flags = PPM_O_RDWR;
 	uint32_t mode = 0;
@@ -617,7 +735,16 @@ TEST_F(sinsp_with_test_input, fchown)
 
 	// We need to open a fd first so fchmod can act on it
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_E, 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_X, 6, fd, path, flags, mode, dev, ino);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_X,
+	                           6,
+	                           fd,
+	                           path,
+	                           flags,
+	                           mode,
+	                           dev,
+	                           ino);
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/tmp/test");
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "3");
 
@@ -627,27 +754,24 @@ TEST_F(sinsp_with_test_input, fchown)
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), "3");
 }
 
-TEST_F(sinsp_with_test_input, memfd_create)
-{
+TEST_F(sinsp_with_test_input, memfd_create) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
-	const char *name = "test_name";
+	const char* name = "test_name";
 	int64_t fd = 4;
 
 	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_MEMFD_CREATE_E, 0);
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_MEMFD_CREATE_X, 3, fd, name, 0);
-	
+
 	ASSERT_EQ(evt->get_type(), PPME_SYSCALL_MEMFD_CREATE_X);
 	ASSERT_EQ(get_field_as_string(evt, "fd.num"), std::to_string(fd));
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), name);
-	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "m"); 
+	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "m");
 	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "memfd");
-
 }
 
-TEST_F(sinsp_with_test_input, test_fdtypes)
-{
+TEST_F(sinsp_with_test_input, test_fdtypes) {
 	add_default_init_thread();
 
 	open_inspector();
@@ -655,8 +779,23 @@ TEST_F(sinsp_with_test_input, test_fdtypes)
 
 	// since adding and reading events happens on a single thread they can be interleaved.
 	// tests may need to change if that will not be the case anymore
-	add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_E, 3, "/tmp/the_file", (uint32_t) PPM_O_RDWR, (uint32_t) 0);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_OPEN_X, 6, (uint64_t) 1, "/tmp/the_file", (uint32_t) PPM_O_RDWR, (uint32_t) 0, (uint32_t) 5, (uint64_t) 123);
+	add_event_advance_ts(increasing_ts(),
+	                     1,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     "/tmp/the_file",
+	                     (uint32_t)PPM_O_RDWR,
+	                     (uint32_t)0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_OPEN_X,
+	                           6,
+	                           (uint64_t)1,
+	                           "/tmp/the_file",
+	                           (uint32_t)PPM_O_RDWR,
+	                           (uint32_t)0,
+	                           (uint32_t)5,
+	                           (uint64_t)123);
 
 	ASSERT_EQ(evt->get_type(), PPME_SYSCALL_OPEN_X);
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/tmp/the_file");
@@ -681,8 +820,7 @@ TEST_F(sinsp_with_test_input, test_fdtypes)
 	ASSERT_EQ(get_field_as_string(evt, "fd.types"), "(bpf,file)");
 }
 
-TEST_F(sinsp_with_test_input, test_pidfd)
-{
+TEST_F(sinsp_with_test_input, test_pidfd) {
 	add_default_init_thread();
 	open_inspector();
 	sinsp_evt* evt = NULL;
@@ -692,25 +830,40 @@ TEST_F(sinsp_with_test_input, test_pidfd)
 	int64_t fd = 4;
 
 	/* Open a file descriptor */
-	add_event_advance_ts(increasing_ts(), pid, PPME_SYSCALL_OPEN_X, 6, (uint64_t)target_fd, "/tmp/the_file", PPM_O_RDWR, 0, 5, (uint64_t)123);
-
+	add_event_advance_ts(increasing_ts(),
+	                     pid,
+	                     PPME_SYSCALL_OPEN_X,
+	                     6,
+	                     (uint64_t)target_fd,
+	                     "/tmp/the_file",
+	                     PPM_O_RDWR,
+	                     0,
+	                     5,
+	                     (uint64_t)123);
 
 	/* Create a pidfd using the same pid */
 	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIDFD_OPEN_X, 3, pidfd, pid, 0);
-	
+
 	ASSERT_EQ(evt->get_type(), PPME_SYSCALL_PIDFD_OPEN_X);
-	ASSERT_EQ(get_field_as_string(evt,"fd.num"), std::to_string(pidfd));
-	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"),"P");
-	ASSERT_EQ(get_field_as_string(evt, "fd.type"),"pidfd");
+	ASSERT_EQ(get_field_as_string(evt, "fd.num"), std::to_string(pidfd));
+	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "P");
+	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "pidfd");
 
 	/* Duplicate the created fd created that is refrenced in pidfd */
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_PIDFD_GETFD_X, 4, fd, pidfd, target_fd, 0);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_PIDFD_GETFD_X,
+	                           4,
+	                           fd,
+	                           pidfd,
+	                           target_fd,
+	                           0);
 
 	ASSERT_EQ(evt->get_type(), PPME_SYSCALL_PIDFD_GETFD_X);
-	ASSERT_EQ(get_field_as_string(evt,"fd.num"), std::to_string(fd));
+	ASSERT_EQ(get_field_as_string(evt, "fd.num"), std::to_string(fd));
 	ASSERT_EQ(get_field_as_string(evt, "fd.name"), "/tmp/the_file");
 	ASSERT_EQ(get_field_as_string(evt, "fd.directory"), "/tmp");
 	ASSERT_EQ(get_field_as_string(evt, "fd.filename"), "the_file");
-	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"),"f");
-	ASSERT_EQ(get_field_as_string(evt, "fd.type"),"file");
+	ASSERT_EQ(get_field_as_string(evt, "fd.typechar"), "f");
+	ASSERT_EQ(get_field_as_string(evt, "fd.type"), "file");
 }
