@@ -25,4 +25,8 @@ void get_plugin_api_sample_syscall_parse(plugin_api& out);
 void get_plugin_api_sample_syscall_async(plugin_api& out);
 void get_plugin_api_sample_plugin_source(plugin_api& out);
 void get_plugin_api_sample_plugin_extract(plugin_api& out);
-void get_plugin_api_sample_tables(plugin_api& out);
+void get_plugin_api_sample_syscall_tables(plugin_api& out);
+void get_plugin_api_sample_syscall_subtables(plugin_api& out);
+void get_plugin_api_sample_syscall_subtables_array(plugin_api& out);
+void get_plugin_api_sample_metrics(plugin_api& out);
+void get_plugin_api_sample_routines(plugin_api& out);
